@@ -172,8 +172,6 @@ struct ast_bridge_video_mode {
  * \brief Destroy the bridge.
  *
  * \param self Bridge to operate upon.
- *
- * \return Nothing
  */
 typedef void (*ast_bridge_destructor_fn)(struct ast_bridge *self);
 
@@ -187,8 +185,6 @@ typedef void (*ast_bridge_destructor_fn)(struct ast_bridge *self);
  * references to the bridge so it can be destroyed.
  *
  * \note On entry, self must NOT be locked.
- *
- * \return Nothing
  */
 typedef void (*ast_bridge_dissolving_fn)(struct ast_bridge *self);
 
@@ -224,8 +220,6 @@ typedef int (*ast_bridge_push_channel_fn)(struct ast_bridge *self, struct ast_br
  * bridge_channel->bridge_pvt.
  *
  * \note On entry, self is already locked.
- *
- * \return Nothing
  */
 typedef void (*ast_bridge_pull_channel_fn)(struct ast_bridge *self, struct ast_bridge_channel *bridge_channel);
 
@@ -240,8 +234,6 @@ typedef void (*ast_bridge_pull_channel_fn)(struct ast_bridge *self, struct ast_b
  * to re-evaluate this a channel in the bridge.
  *
  * \note On entry, self is already locked.
- *
- * \return Nothing
  */
 typedef void (*ast_bridge_notify_masquerade_fn)(struct ast_bridge *self, struct ast_bridge_channel *bridge_channel);
 
@@ -423,10 +415,10 @@ extern struct ast_bridge_methods ast_bridge_base_v_table;
  * \brief Returns the global bridges container
  * \since 17.0
  *
- * \retval a pointer to the bridges container success
+ * \return a pointer to the bridges container success
  * \retval NULL on failure
  *
- * \note You must use ao2_ref(<container>, -1) when done with it
+ * \note You must use \verbatim ao2_ref(<container>, -1) \endverbatim when done with it
  *
  * \warning You must not attempt to modify the container returned.
  */
@@ -441,7 +433,7 @@ struct ao2_container *ast_bridges(void);
  * \param name Name given to the bridge by its creator (optional, requires named creator)
  * \param id Unique ID given to the bridge by its creator (optional)
  *
- * \retval a pointer to a new bridge on success
+ * \return a pointer to a new bridge on success
  * \retval NULL on failure
  *
  * Example usage:
@@ -474,8 +466,6 @@ static inline int _ast_bridge_trylock(struct ast_bridge *bridge, const char *fil
  * \brief Lock the bridge.
  *
  * \param bridge Bridge to lock
- *
- * \return Nothing
  */
 #define ast_bridge_lock(bridge)	_ast_bridge_lock(bridge, __FILE__, __PRETTY_FUNCTION__, __LINE__, #bridge)
 static inline void _ast_bridge_lock(struct ast_bridge *bridge, const char *file, const char *function, int line, const char *var)
@@ -487,8 +477,6 @@ static inline void _ast_bridge_lock(struct ast_bridge *bridge, const char *file,
  * \brief Unlock the bridge.
  *
  * \param bridge Bridge to unlock
- *
- * \return Nothing
  */
 #define ast_bridge_unlock(bridge)	_ast_bridge_unlock(bridge, __FILE__, __PRETTY_FUNCTION__, __LINE__, #bridge)
 static inline void _ast_bridge_unlock(struct ast_bridge *bridge, const char *file, const char *function, int line, const char *var)
@@ -539,8 +527,6 @@ int ast_bridge_destroy(struct ast_bridge *bridge, int cause);
  * \since 12.0.0
  *
  * \param chan Channel just involved in a masquerade
- *
- * \return Nothing
  */
 void ast_bridge_notify_masquerade(struct ast_channel *chan);
 
@@ -803,8 +789,6 @@ int ast_bridge_move(struct ast_bridge *dst_bridge, struct ast_bridge *src_bridge
  * \param bridge What to operate on.
  * \param request Inhibit request increment.
  *     (Positive to add requests.  Negative to remove requests.)
- *
- * \return Nothing
  */
 void ast_bridge_merge_inhibit(struct ast_bridge *bridge, int request);
 
@@ -860,10 +844,9 @@ int ast_bridge_unsuspend(struct ast_bridge *bridge, struct ast_channel *chan);
  *
  * \pre chan must be locked before calling
  *
- * \param name channel name of the bridged peer
+ * \param chan channel name of the bridged peer
+ * \param name
  * \param pvtid Private CallID of the bridged peer
- *
- * \return nothing
  */
 void ast_bridge_vars_set(struct ast_channel *chan, const char *name, const char *pvtid);
 
@@ -919,7 +902,7 @@ enum ast_bridge_optimization {
  * AST_BRIDGE_OPTIMIZE_PROHIBITED guarantees that an optimization attempt will
  * never succeed.
  *
- * \returns Optimization allowability for the bridges
+ * \return Optimization allowability for the bridges
  */
 enum ast_bridge_optimization ast_bridges_allow_optimization(struct ast_bridge *chan_bridge,
 		struct ast_bridge *peer_bridge);
@@ -1056,7 +1039,7 @@ void ast_bridge_set_remb_estimated_bitrate(struct ast_bridge *bridge, float esti
 /*!
  * \brief Update information about talker energy for talker src video mode.
  */
-void ast_bridge_update_talker_src_video_mode(struct ast_bridge *bridge, struct ast_channel *chan, int talker_energy, int is_keyfame);
+void ast_bridge_update_talker_src_video_mode(struct ast_bridge *bridge, struct ast_channel *chan, int talker_energy, int is_keyframe);
 
 /*!
  * \brief Returns the number of video sources currently active in the bridge
@@ -1067,7 +1050,7 @@ int ast_bridge_number_video_src(struct ast_bridge *bridge);
  * \brief Determine if a channel is a video src for the bridge
  *
  * \retval 0 Not a current video source of the bridge.
- * \retval None 0, is a video source of the bridge, The number
+ * \retval non-zero is a video source of the bridge, The number
  *         returned represents the priority this video stream has
  *         on the bridge where 1 is the highest priority.
  */
@@ -1083,7 +1066,7 @@ void ast_bridge_remove_video_src(struct ast_bridge *bridge, struct ast_channel *
  *
  * \param video_mode The video mode
  *
- * \retval A string representation of \c video_mode
+ * \return A string representation of \c video_mode
  */
 const char *ast_bridge_video_mode_to_string(enum ast_bridge_video_mode_type video_mode);
 
@@ -1281,8 +1264,6 @@ struct ast_channel *ast_bridge_peer(struct ast_bridge *bridge, struct ast_channe
  *
  * \param features Bridge features structure
  * \param flags Determinator for whether hook is removed.
- *
- * \return Nothing
  */
 void ast_bridge_features_remove(struct ast_bridge_features *features, enum ast_bridge_hook_remove_flags flags);
 
