@@ -19,7 +19,7 @@
 /*! \file
  * \brief Device state management
  *
- * To subscribe to device state changes, use the generic ast_event_subscribe
+ * To subscribe to device state changes, use the stasis_subscribe
  * method.  For an example, see apps/app_queue.c.
  *
  * \todo Currently, when the state of a device changes, the device state provider
@@ -38,6 +38,7 @@
 #define _ASTERISK_DEVICESTATE_H
 
 #include "asterisk/channelstate.h"
+#include "asterisk/utils.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -58,11 +59,11 @@ enum ast_device_state {
 	AST_DEVICE_RINGING,      /*!< Device is ringing */
 	AST_DEVICE_RINGINUSE,    /*!< Device is ringing *and* in use */
 	AST_DEVICE_ONHOLD,       /*!< Device is on hold */
-	AST_DEVICE_TOTAL,        /*/ Total num of device states, used for testing */
+	AST_DEVICE_TOTAL,        /*!< Total num of device states, used for testing */
 };
 
 /*! \brief Device State Cachability
- *  \note This is used to define the cachability of a device state when set.
+ *  \note This is used to define the cacheability of a device state when set.
  */
 enum ast_devstate_cache {
 	AST_DEVSTATE_NOT_CACHABLE,  /*!< This device state is not cachable */
@@ -85,7 +86,6 @@ enum ast_device_state ast_state_chan2dev(enum ast_channel_state chanstate);
  *
  * \param devstate Current device state
  */
-const char *devstate2str(enum ast_device_state devstate) attribute_pure __attribute__((deprecated));
 const char *ast_devstate2str(enum ast_device_state devstate) attribute_pure;
 
 /*!
@@ -128,7 +128,7 @@ enum ast_device_state ast_parse_device_state(const char *device);
  * Tries the channel device state callback if not supported search in the
  * active channels list for the device.
  *
- * \retval an AST_DEVICE_??? state
+ * \return an AST_DEVICE_??? state
  */
 enum ast_device_state ast_device_state(const char *device);
 
@@ -165,41 +165,6 @@ int ast_devstate_changed(enum ast_device_state state, enum ast_devstate_cache ca
  */
 int ast_devstate_changed_literal(enum ast_device_state state, enum ast_devstate_cache cachable, const char *device);
 
-/*!
- * \brief Tells Asterisk the State for Device is changed.
- * (Accept change notification, add it to change queue.)
- *
- * \param fmt device name like a dial string with format parameters
- *
- * Asterisk polls the new extension states and calls the registered
- * callbacks for the changed extensions
- *
- * \retval 0 on success
- * \retval -1 on failure
- *
- * \note This is deprecated in favor of ast_devstate_changed()
- * \version 1.6.1 deprecated
- */
-int ast_device_state_changed(const char *fmt, ...)
-	__attribute__((deprecated,format(printf, 1, 2)));
-
-/*!
- * \brief Tells Asterisk the State for Device is changed
- *
- * \param device device name like a dial string
- *
- * Asterisk polls the new extension states and calls the registered
- * callbacks for the changed extensions
- *
- * \retval 0 on success
- * \retval -1 on failure
- *
- * \note This is deprecated in favor of ast_devstate_changed_literal()
- * \version 1.6.1 deprecated
- */
-int ast_device_state_changed_literal(const char *device)
-	__attribute__((deprecated));
-
 /*!
  * \brief Add device state provider
  *
@@ -231,7 +196,6 @@ struct ast_devstate_aggregate;
  *
  * \param[in] agg the state object
  *
- * \return nothing
  * \since 1.6.1
  */
 void ast_devstate_aggregate_init(struct ast_devstate_aggregate *agg);
@@ -242,7 +206,6 @@ void ast_devstate_aggregate_init(struct ast_devstate_aggregate *agg);
  * \param[in] agg the state object
  * \param[in] state the state to add
  *
- * \return nothing
  * \since 1.6.1
  */
 void ast_devstate_aggregate_add(struct ast_devstate_aggregate *agg, enum ast_device_state state);
@@ -269,19 +232,110 @@ struct ast_devstate_aggregate {
 };
 
 /*!
- * \brief Enable distributed device state processing.
- *
- * \details
- * By default, Asterisk assumes that device state change events will only be
- * originating from one instance.  If a module gets loaded and configured such
- * that multiple instances of Asterisk will be sharing device state, this
- * function should be called to enable distributed device state processing.
- * It is off by default to save on unnecessary processing.
- *
- * \retval 0 success
- * \retval -1 failure
+ * \brief The structure that contains device state
+ * \since 12
  */
-int ast_enable_distributed_devstate(void);
+struct ast_device_state_message {
+	/*! The name of the device */
+	const char *device;
+	/*!
+	 * \brief The EID of the server where this message originated.
+	 *
+	 * \note A NULL EID means aggregate state.
+	 */
+	const struct ast_eid *eid;
+	/*! The state of the device */
+	enum ast_device_state state;
+	/*! Flag designating the cacheability of this device state */
+	enum ast_devstate_cache cachable;
+	/*! The device and eid data is stuffed here when the struct is allocated. */
+	struct ast_eid stuff[0];
+};
+
+/*!
+ * \brief Get the Stasis topic for device state messages
+ * \return The topic for device state messages
+ * \retval NULL if it has not been allocated
+ * \since 12
+ */
+struct stasis_topic *ast_device_state_topic_all(void);
+
+/*!
+ * \brief Get the Stasis topic for device state messages for a specific device
+ * \param device The device for which to get the topic
+ * \return The topic structure for MWI messages for a given device
+ * \retval NULL if it failed to be found or allocated
+ * \since 12
+ */
+struct stasis_topic *ast_device_state_topic(const char *device);
+
+/*!
+ * \brief Get the Stasis caching topic for device state messages
+ * \return The caching topic for device state messages
+ * \retval NULL if it has not been allocated
+ * \since 12
+ */
+struct stasis_topic *ast_device_state_topic_cached(void);
+
+/*!
+ * \brief Backend cache for ast_device_state_topic_cached()
+ * \return Cache of \ref ast_device_state_message.
+ * \since 12
+ */
+struct stasis_cache *ast_device_state_cache(void);
+
+/*!
+ * \brief Get the Stasis message type for device state messages
+ * \return The message type for device state messages
+ * \retval NULL if it has not been allocated
+ * \since 12
+ */
+struct stasis_message_type *ast_device_state_message_type(void);
+
+/*!
+ * \brief Clear the device from the stasis cache.
+ * \param device The device to clear
+ * \retval 0 if successful
+ * \retval -1 nothing to clear
+ * \since 12
+ */
+int ast_device_state_clear_cache(const char *device);
+
+/*!
+ * \brief Initialize the device state core
+ * \retval 0 Success
+ * \retval -1 Failure
+ * \since 12
+ */
+int devstate_init(void);
+
+/*!
+ * \brief Publish a device state update
+ * \param[in] device The device name
+ * \param[in] state The state of the device
+ * \param[in] cachable Whether the device state can be cached
+ * \retval 0 Success
+ * \retval -1 Failure
+ * \since 12
+ */
+#define ast_publish_device_state(device, state, cachable) \
+	ast_publish_device_state_full(device, state, cachable, &ast_eid_default)
+
+/*!
+ * \brief Publish a device state update with EID
+ * \param[in] device The device name
+ * \param[in] state The state of the device
+ * \param[in] cachable Whether the device state can be cached
+ * \param[in] eid The EID of the server that originally published the message
+ * \retval 0 Success
+ * \retval -1 Failure
+ * \since 12
+ */
+int ast_publish_device_state_full(
+			const char *device,
+			enum ast_device_state state,
+			enum ast_devstate_cache cachable,
+			struct ast_eid *eid);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
