@@ -165,6 +165,20 @@ struct ast_datastore *ast_sip_publication_get_datastore(struct ast_sip_publicati
  */
 void ast_sip_publication_remove_datastore(struct ast_sip_publication *publication, const char *name);
 
+/*!
+ * \brief Get the datastores container for a publication
+ *
+ * \param publication The publication to get the datastores container from
+ *
+ * \retval NULL datastores container not present
+ * \retval non-NULL datastores container
+ *
+ * \note The container is NOT returned with reference count bumped
+ *
+ * \since 14.0.0
+ */
+struct ao2_container *ast_sip_publication_get_datastores(const struct ast_sip_publication *publication);
+
 /*!
  * \brief Opaque structure representing an RFC 3265 SIP subscription
  */
@@ -214,9 +228,9 @@ enum ast_sip_subscription_notify_reason {
 	AST_SIP_SUBSCRIPTION_NOTIFY_REASON_OTHER
 };
 
-/*! Type used for conveying mailbox state */
-#define AST_SIP_EXTEN_STATE_DATA "ast_sip_exten_state_data"
 /*! Type used for extension state/presence */
+#define AST_SIP_EXTEN_STATE_DATA "ast_sip_exten_state_data"
+/*! Type used for conveying mailbox state */
 #define AST_SIP_MESSAGE_ACCUMULATOR "ast_sip_message_accumulator"
 
 /*!
@@ -278,6 +292,17 @@ struct ast_sip_notifier {
 	 * \return An ao2 object that can be used to create a NOTIFY body.
 	 */
 	void *(*get_notify_data)(struct ast_sip_subscription *sub);
+	/*!
+	 * \brief Supply Display Name for resource
+	 *
+	 * \param endpoint The endpoint from which we received the SUBSCRIBE
+	 * \param resource The name of the resource to which the subscription is being made
+	 * \param display_name buffer for Display Name
+	 * \param display_name_size size of display_name buffer
+	 * \retval 0 Success
+	 * \retval -1 Failure
+	 */
+	int (*get_resource_display_name)(struct ast_sip_endpoint *endpoint, const char *resource, char *display_name, int display_name_size);
 };
 
 struct ast_sip_subscriber {
@@ -332,7 +357,7 @@ struct ast_sip_subscription_handler {
  * When a subscriber wishes to create a subscription, it may call this function
  * to allocate resources and to send the initial SUBSCRIBE out.
  *
- * \param subscriber The subscriber that is making the request.
+ * \param handler The subscriber that is making the request.
  * \param endpoint The endpoint to whome the SUBSCRIBE will be sent.
  * \param resource The resource to place in the SUBSCRIBE's Request-URI.
  */
@@ -517,6 +542,43 @@ struct ast_datastore *ast_sip_subscription_get_datastore(struct ast_sip_subscrip
  */
 void ast_sip_subscription_remove_datastore(struct ast_sip_subscription *subscription, const char *name);
 
+/*!
+ * \brief Get the datastores container for a subscription
+ *
+ * \param subscription The subscription to get the datastores container from
+ *
+ * \retval NULL datastores container not present
+ * \retval non-NULL datastores container
+ *
+ * \note The container is NOT returned with reference count bumped
+ *
+ * \since 14.0.0
+ */
+struct ao2_container *ast_sip_subscription_get_datastores(const struct ast_sip_subscription *subscription);
+
+/*!
+ * \since 13.31.0
+ * \since 16.8.0
+ * \since 17.2.0
+ * \brief Set persistence data for a subscription
+ *
+ * \param subscription The subscription to set persistence data on
+ * \param persistence_data The persistence data to set
+ *
+ * \note This steals the reference to persistence_data
+ */
+void ast_sip_subscription_set_persistence_data(struct ast_sip_subscription *subscription, struct ast_json *persistence_data);
+
+/*!
+ * \since 13.31.0
+ * \since 16.8.0
+ * \since 17.2.0
+ * \brief Retrieve persistence data for a subscription
+ *
+ * \param subscription The subscription to retrieve persistence data from
+ */
+const struct ast_json *ast_sip_subscription_get_persistence_data(const struct ast_sip_subscription *subscription);
+
 /*!
  * \brief Register a subscription handler
  *
@@ -648,6 +710,19 @@ struct ast_sip_pubsub_body_supplement {
 int ast_sip_pubsub_generate_body_content(const char *content_type,
 		const char *content_subtype, struct ast_sip_body_data *data, struct ast_str **str);
 
+/*!
+ * \brief Is a body generator registered for the given type/subtype.
+ * \since 14.0.0
+ *
+ * \param type The content type of the body
+ * \param subtype The content subtype of the body
+ *
+ * \note In "plain/text", "plain" is the type and "text" is the subtype.
+ *
+ * \retval non-zero if a generator is registered.
+ */
+int ast_sip_pubsub_is_body_generator_registered(const char *type, const char *subtype);
+
 /*!
  * \since 13.0.0
  * \brief Register a body generator with the pubsub core.
@@ -678,7 +753,7 @@ void ast_sip_pubsub_unregister_body_generator(struct ast_sip_pubsub_body_generat
  * for a given content type if a primary body supplement for that content type
  * has already been registered.
  *
- * \param generator Body generator to register
+ * \param supplement Body generator to register
  * \retval 0 Success
  * \retval -1 Failure
  */
@@ -688,7 +763,7 @@ int ast_sip_pubsub_register_body_supplement(struct ast_sip_pubsub_body_supplemen
  * \since 13.0.0
  * \brief Unregister a body generator with the pubsub core.
  *
- * \param generator Body generator to unregister
+ * \param supplement Body generator to unregister
  */
 void ast_sip_pubsub_unregister_body_supplement(struct ast_sip_pubsub_body_supplement *supplement);
 
@@ -709,17 +784,7 @@ const char *ast_sip_subscription_get_body_subtype(struct ast_sip_subscription *s
  * \brief Alert the pubsub core that the subscription is ready for destruction
  *
  * \param sub The subscription that is complete
- * \return Nothing
  */
 void ast_sip_subscription_destroy(struct ast_sip_subscription *sub);
 
-/*! \brief Determines whether the res_pjsip_pubsub module is loaded */
-#define CHECK_PJSIP_PUBSUB_MODULE_LOADED()			\
-	do {							\
-		CHECK_PJSIP_MODULE_LOADED();			\
-		if (!ast_module_check("res_pjsip_pubsub.so")) {	\
-			return AST_MODULE_LOAD_DECLINE;		\
-		}						\
-	} while(0)
-
 #endif /* RES_PJSIP_PUBSUB_H */
