@@ -163,6 +163,7 @@ void ast_xml_free_text(const char *text);
  * \param attrname Attribute name.
  * \retval NULL on error
  * \return The attribute value on success.
+ * \note The result must be freed with ast_xml_free_attr().
  */
 const char *ast_xml_get_attribute(struct ast_xml_node *node, const char *attrname);
 
@@ -188,6 +189,18 @@ int ast_xml_set_attribute(struct ast_xml_node *node, const char *name, const cha
 struct ast_xml_node *ast_xml_find_element(struct ast_xml_node *root_node, const char *name, const char *attrname, const char *attrvalue);
 struct ast_xml_ns *ast_xml_find_namespace(struct ast_xml_doc *doc, struct ast_xml_node *node, const char *ns_name);
 
+/*!
+ * \brief Find a direct child element by name.
+ * \param _parent_node This is the parent node to search.
+ * \param _name Node name to find.
+ * \param _attrname attribute name to match (if NULL it won't be matched).
+ * \param _attrvalue attribute value to match (if NULL it won't be matched).
+ * \retval NULL if not found.
+ * \return The node on success.
+ */
+#define ast_xml_find_child_element(_parent_node, _name, _attrname, _attrvalue) \
+    ast_xml_find_element(ast_xml_node_get_children(_parent_node), _name, _attrname, _attrvalue)
+
 /*!
  * \brief Get the prefix of a namespace.
  * \param ns The namespace
@@ -248,6 +261,17 @@ struct ast_xml_node *ast_xml_node_get_parent(struct ast_xml_node *node);
  * \brief Dump the specified document to a file. */
 int ast_xml_doc_dump_file(FILE *output, struct ast_xml_doc *doc);
 
+/*!
+ * \brief Dump the specified document to a buffer
+ *
+ * \param doc The XML doc to dump
+ * \param buffer A pointer to a char * to receive the address of the results
+ * \param length A pointer to an int to receive the length of the results
+ *
+ * \note The result buffer must be freed with ast_xml_free_text().
+ */
+void ast_xml_doc_dump_memory(struct ast_xml_doc *doc, char **buffer, int *length);
+
 /*!
  * \brief Free the XPath results
  * \param results The XPath results object to dispose of
@@ -347,7 +371,7 @@ void ast_xslt_close(struct ast_xslt_doc *xslt);
  * \brief Apply an XSLT stylesheet to an XML document
  *
  * \param xslt    XSLT stylesheet to apply.
- * \param xml     XML document the stylesheet will be applied to.
+ * \param doc     XML document the stylesheet will be applied to.
  * \param params  An array of name value pairs to pass as parameters
  *                The array must terminate with a NULL sentinel.
  *                Example:  { "name1", "value1", "name2", "value2", NULL }
@@ -359,11 +383,11 @@ struct ast_xml_doc *ast_xslt_apply(struct ast_xslt_doc *xslt, struct ast_xml_doc
 /*!
  * \brief Save the results of applying a stylesheet to a string
  *
- * \param buffer[out]  A pointer to a char * to receive the address of the result string.
+ * \param[out] buffer  A pointer to a char * to receive the address of the result string.
  *                     The buffer must be freed with ast_xml_free_text().
- * \param length[out]  A pointer to an int to receive the result string length.
- * \param result       The result document from ast_xslt_apply.
- * \param xslt         The stylesheet that was applied.
+ * \param[out] length  A pointer to an int to receive the result string length.
+ * \param      result  The result document from ast_xslt_apply.
+ * \param      xslt    The stylesheet that was applied.
  *
  * \return 0 on success, any other value on failure.
  */
